#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2020-06-07
#
# 2023-03-04: moved wato file from ~/local/share/check_mk/... to ~/local/lib/check_mk/...
#             fix: CheckParameterRulespecWithItem -> CheckParameterRulespecWithoutItem
#             changed levels_upper_absolute/levels_upper_relative from Tuple to Levels for predictive monitoring
# 2023-05-29: added dummy for checkpoint_connections

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    Tuple,
    Integer,
    Percentage,
    FixedValue,
)
from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithoutItem,
    rulespec_registry,
    RulespecGroupCheckParametersNetworking,
    RulespecGroupCheckParametersApplications,
    Levels,
)


def _parameter_valuespec_checkpoint_fw_connections():
    return Dictionary(
        elements=[
            ('admin_table_limit',
             Integer(
                 title=_('Connection table limit'),
                 help=_('This sets the maximum number of connections through the firewall. This is use full '
                        'if your firewall is set to automatic connection table limit and you still want '
                        'relative metrics. This setting takes precedence over the the onnection table limit '
                        'configured on the firewall (only for monitoring purposes of curse). This value should match '
                        'the real values of your firewall, if not you might get relative values above 100%.'),
                 minvalue=0,
                 unit=_('connections'),
             )),
            ('levels_upper_absolute',
             Levels(
                 title=_('Max. connections (Absolute)'),
                 help=_('This sets the upper limits for the current number of connections through the firewall.'),
                 unit=_('connections'),
             )),
            ('levels_lower_absolute',
             Tuple(
                 title=_('Min. connections (Absolute)'),
                 help=_('This sets the lower limits for the current number of connections through the firewall. '
                        '"Min. connections (Absolute)" will only be used if "Max. connections (Absolute)" is not using '
                        'Predictive Levels.'),
                 elements=[
                     Integer(title=_('Warning blow'), minvalue=0, unit=_('connections')),
                     Integer(title=_('Critical below'), minvalue=0, unit=_('connections')),
                 ])),
            ('levels_upper_relative',
             Levels(
                 title=_('Max. connections (Percentage)'),
                 help=_('This relative threshold can only be used if a connection table limit is defined (on the '
                        'firewall side or with the above "Connection table limit").By default, this limit is not '
                        'set on Check Point devices.'),
                 unit=_('%'),
             )),
            ('levels_lower_relative',
             Tuple(
                 title=_('Min. connections (Percentage)'),
                 help=_('This relative threshold can only be used if a maximum number is defined (on the '
                        'firewall side or with the above "Connection table limit"). By default, this limit is not '
                        'set on Check Point devices.'),
                 elements=[
                     Percentage(
                         title=_('Warning below'), unit='%', minvalue=0.0, maxvalue=100.0),
                     Percentage(
                         title=_('Critical below'), unit='%', minvalue=0.0, maxvalue=100.0),
                 ])),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name='checkpoint_fw_connections',
        group=RulespecGroupCheckParametersNetworking,
        match_type='dict',
        parameter_valuespec=_parameter_valuespec_checkpoint_fw_connections,
        title=lambda: _('Check Point Firewall Connections'),
    ))


def _parameter_valuespec_checkpoint_connections():
    return Dictionary(
        [
            ('non_value',
             FixedValue(
                 title=_('This rule set is superseded by "Check Point Firewall Connections".'),
                 value=False,
                 totext='',
             ))
            # (
            #     "levels",
            #     Tuple(
            #         help=_(
            #             "This rule sets limits to the current number of connections through "
            #             "a Checkpoint firewall."
            #         ),
            #         title=_("Maximum number of firewall connections"),
            #         elements=[
            #             Integer(
            #                 title=_("Warning at"),
            #                 minvalue=0,
            #                 default_value=40000,
            #                 unit=_("connections"),
            #             ),
            #             Integer(
            #                 title=_("Critical at"),
            #                 minvalue=0,
            #                 default_value=50000,
            #                 unit=_("connections"),
            #             ),
            #         ],
            #     ),
            # ),
        ],
        optional_keys=False,
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name="checkpoint_connections",
        group=RulespecGroupCheckParametersApplications,
        parameter_valuespec=_parameter_valuespec_checkpoint_connections,
        title=lambda: _("Checkpoint Firewall Connections"),
    )
)
